/*_############################################################################
  _## 
  _##  SNMP4J-AgentJMX - JMXAttributeNotificationIndexSupport.java  
  _## 
  _##  Copyright (C) 2006-2009  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/

package org.snmp4j.agent.mo.jmx;

import org.snmp4j.smi.OID;
import org.snmp4j.agent.mo.jmx.types.TypedAttribute;
import javax.management.openmbean.CompositeDataSupport;

/**
 * Notification objects can refer to scalar and tabular data. Whereas for scalar
 * data the OID of the instance is constant, the index portion of the instance
 * identifier of tabular data may vary from notification to notification.
 * <p>
 * The <code>JMXAttributeNotificationIndexSupport</code> provides the index
 * portion for a notification object by using a <code>JMXIndexSupport</code>
 * instance. That instance can be shared with the table holding the target
 * object.
 *
 * @author Frank Fock
 * @version 1.0
 */
public class JMXAttributeNotificationIndexSupport
    implements JMXNotificationIndexSupport
{
  private TypedAttribute attribute;
  private JMXIndexSupport indexSupport;
  private OID index;

  public JMXAttributeNotificationIndexSupport(TypedAttribute attribute,
                                              JMXIndexSupport indexSupport) {
    this.attribute = attribute;
    this.indexSupport = indexSupport;
  }

  public void intialize(Object notificationUserObject) {
    Object key = notificationUserObject;
    if (notificationUserObject instanceof CompositeDataSupport) {
      key = ((CompositeDataSupport)
             notificationUserObject).get(attribute.getName());
    }
    index = indexSupport.mapToIndex(key);
  }

  public OID getIndex(int objectIndex) {
    return index;
  }
}
