/*_############################################################################
  _## 
  _##  SNMP4J-AgentJMX - MBeanInvokationKeyProvider.java  
  _## 
  _##  Copyright (C) 2006-2009  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/

package org.snmp4j.agent.mo.jmx;

import javax.management.ObjectName;
import org.snmp4j.agent.mo.jmx.types.TypedAttribute;
import javax.management.MBeanServerConnection;
import java.io.IOException;
import javax.management.MBeanException;
import javax.management.AttributeNotFoundException;
import javax.management.InstanceNotFoundException;
import javax.management.ReflectionException;

/**
 * If a MBean provides the keys for a SNMP conceptual table by an attribute
 * and the objects that represent rows of that table can be accessed through
 * a call to an operation of that MBean then this class can be used to provide
 * the row objects for the SNMP conceptual table.
 *
 * @author Frank Fock
 * @version 1.0
 */
public class MBeanInvokationKeyProvider extends MBeanAttributeKeyProvider {

  private String rowProvidingOperation;

  public MBeanInvokationKeyProvider(ObjectName mBeanName,
                                    TypedAttribute keyAttribute,
                                    String rowProvidingOperation) {
    super(mBeanName, keyAttribute);
    this.rowProvidingOperation = rowProvidingOperation;
  }

  public MBeanInvokationKeyProvider(ObjectName mBeanName,
                                    TypedAttribute keyAttribute,
                                    String rowProvidingOperation,
                                    boolean keysNeedSorting) {
    super(mBeanName, keyAttribute, keysNeedSorting);
    this.rowProvidingOperation = rowProvidingOperation;
  }

  public Object getRowValues(MBeanServerConnection server, Object indexObject)
      throws IOException, MBeanException, AttributeNotFoundException,
      InstanceNotFoundException, ReflectionException
  {
    Object row =
        server.invoke(getObjectName(), rowProvidingOperation,
                      new Object[] { indexObject },
                      new String[] { getAttribute().getType().getName() });
    return row;
  }

}
